==> oci-java-sdk-networkloadbalancer-1.34.0-sources.jar: com/oracle/bmc/networkloadbalancer/model/HealthCheckProtocols.java <==
/**
 * Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.networkloadbalancer.model;

/**
 * Protocols supported for the health checks of the network load balancer.
 **/
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200501")
@lombok.extern.slf4j.Slf4j
public enum HealthCheckProtocols {
    Http("HTTP"),
    Https("HTTPS"),
    Tcp("TCP"),
    Udp("UDP"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private final String value;
    private static java.util.Map<String, HealthCheckProtocols> map;

    static {
        map = new java.util.HashMap<>();
        for (HealthCheckProtocols v : HealthCheckProtocols.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    HealthCheckProtocols(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static HealthCheckProtocols create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'HealthCheckProtocols', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}

==> oci-java-sdk-networkloadbalancer-3.0.1-sources.jar: com/oracle/bmc/networkloadbalancer/model/HealthCheckProtocols.java <==
/**
 * Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.networkloadbalancer.model;

/** Protocols supported for the health checks of the network load balancer. */
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200501")
public enum HealthCheckProtocols implements com.oracle.bmc.http.internal.BmcEnum {
    Http("HTTP"),
    Https("HTTPS"),
    Tcp("TCP"),
    Udp("UDP"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private static final org.slf4j.Logger LOG =
            org.slf4j.LoggerFactory.getLogger(HealthCheckProtocols.class);

    private final String value;
    private static java.util.Map<String, HealthCheckProtocols> map;

    static {
        map = new java.util.HashMap<>();
        for (HealthCheckProtocols v : HealthCheckProtocols.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    HealthCheckProtocols(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static HealthCheckProtocols create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'HealthCheckProtocols', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}
